@@ -1,17 +1,14 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package OpenGbg::Service::AirQuality::GetLatestMeasurement;
 
-our $VERSION = '0.1302'; # VERSION
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Get the latest air quality measurement
 
-use OpenGbg::Types -types;
-use Kavorka;
 use XML::Rabbit::Root;
-use DateTime::Format::HTTP;
-use MooseX::AttributeShortcuts;
+use Types::Standard qw/Str/;
 
 has xml => (
     is => 'ro',
@@ -39,7 +36,7 @@ OpenGbg::Service::AirQuality::GetLatestMeasurement - Get the latest air quality
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
 
 =head1 SYNOPSIS
 
@@ -68,7 +65,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
