@@ -1,17 +1,15 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package OpenGbg::Service::AirQuality::GetMeasurements;
 
-our $VERSION = '0.1302'; # VERSION
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Get a collection of measurements
 
-use OpenGbg::Types -types;
 use XML::Rabbit::Root;
-use DateTime::Format::HTTP;
 use MooseX::AttributeShortcuts;
-use Kavorka;
+use Types::Standard qw/Str/;
 
 has xml => (
     is => 'ro',
@@ -39,7 +37,11 @@ OpenGbg::Service::AirQuality::GetMeasurements - Get a collection of measurements
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
+
+=head1 NAME
+
+OpenGbg::Service::AirQuality::GetMeasurements
 
 =head1 SYNOPSIS
 
@@ -48,10 +50,6 @@ Version 0.1302, released 2015-01-17.
 
     print $response->measurements->get_by_index(5)->to_text;
 
-=head1 NAME
-
-OpenGbg::Service::AirQuality::GetMeasurements
-
 =head1 METHODS
 
 =head2 measurements
@@ -72,7 +70,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
