@@ -1,17 +1,16 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package OpenGbg::Service::Bridge::GetIsCurrentlyOpen;
 
-our $VERSION = '0.1302'; # VERSION
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Is the bridge currently open?
 
-use OpenGbg::Types -types;
 use XML::Rabbit::Root;
 use DateTime::Format::HTTP;
 use MooseX::AttributeShortcuts;
-use Kavorka;
+use Types::Standard qw/Str Bool/;
 
 has xml => (
     is => 'ro',
@@ -30,11 +29,10 @@ has is_open => (
     builder => 1,
 );
 
-method _build_is_open {
-    return $self->_is_open eq 'true';
+sub _build_is_open {
+    return shift->_is_open eq 'true';
 }
 
-
 finalize_class();
 
 1;
@@ -51,7 +49,7 @@ OpenGbg::Service::Bridge::GetIsCurrentlyOpen - Is the bridge currently open?
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
 
 =head1 SYNOPSIS
 
@@ -80,7 +78,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
