@@ -1,17 +1,15 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package OpenGbg::Service::Bridge::GetOpenedStatus;
 
-our $VERSION = '0.1302'; # VERSION
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: A list of bridge openings
 
-use OpenGbg::Types -types;
 use XML::Rabbit::Root;
-use DateTime::Format::HTTP;
 use MooseX::AttributeShortcuts;
-use Kavorka;
+use Types::Standard qw/Str/;
 
 has xml => (
     is => 'ro',
@@ -39,7 +37,7 @@ OpenGbg::Service::Bridge::GetOpenedStatus - A list of bridge openings
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
 
 =head1 SYNOPSIS
 
@@ -73,7 +71,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
