@@ -1,46 +1,59 @@
-use OpenGbg::Standard::Imports;
+use 5.10.1;
+use strict;
+use warnings;
 
-our $VERSION = '0.1302'; # VERSION
-# PODNAME: OpenGbg::Service::StyrOchStall
+package OpenGbg::Service::StyrOchStall;
+
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Entry point to the StyrOchStall bike rental service
 
-class OpenGbg::Service::StyrOchStall
-using Moose
- with OpenGbg::Service::Getter {
+use OpenGbg::Elk;
+with 'OpenGbg::Service::Getter';
 
-    use OpenGbg::Service::StyrOchStall::GetBikeStation;
+use namespace::autoclean;
+use Types::Standard qw/Str/;
 
-    has handler => (
-        is => 'ro',
-        required => 1,
-    );
-    has service_base => (
-        is => 'rw',
-        isa => Str,
-        default => 'StyrOchStall/v0.1/',
-    );
+use OpenGbg::Service::StyrOchStall::GetBikeStation;
+use OpenGbg::Service::StyrOchStall::GetBikeStations;
 
-    method get_bike_station($id) {
-        my $url = "GetBikeStation/$id/%s?";
-        my $response = $self->getter($url, 'get_bike_station');
+has handler => (
+    is => 'ro',
+    required => 1,
+);
+has service_base => (
+    is => 'rw',
+    isa => Str,
+    default => 'StyrOchStall/v0.1/',
+);
 
-        return OpenGbg::Service::StyrOchStall::GetBikeStation->new(xml => $response);
-    }
+sub get_bike_station {
+    my $self = shift;
+    my $id = shift;
 
-    method get_bike_stations(:$lat = undef, :$long = undef, :$radius = undef) {
-        my $geo = '';
-        if($lat && $long && $radius) {
-            my %hash = ( latitude => $lat, longitude => $long, radius => $radius );
-            $geo = join '&' => map { "$_=$hash{ $_ }" } keys %hash;
-        }
+    my $url = "GetBikeStation/$id/%s?";
+    my $response = $self->getter($url, 'get_bike_station');
 
-        my $url = "GetBikeStations/%s?$geo&";
-        my $response = $self->getter($url, 'get_bike_stations');
-
-        return OpenGbg::Service::StyrOchStall::GetBikeStations->new(xml => $response);
-    }
+    return OpenGbg::Service::StyrOchStall::GetBikeStation->new(xml => $response);
 }
 
+sub get_bike_stations {
+    my $self = shift;
+    my %args = @_;
+
+    my $geo = '';
+    if(exists $args{'lat'} && exists $args{'long'}) {
+        my %hash = ( latitude => $args{'lat'}, longitude => $args{'long'}, radius => $args{'radius'} );
+        $geo = join '&' => map { "$_=$hash{ $_ }" } keys %hash;
+    }
+
+    my $url = "GetBikeStations/%s?$geo&";
+    my $response = $self->getter($url, 'get_bike_stations');
+
+    return OpenGbg::Service::StyrOchStall::GetBikeStations->new(xml => $response);
+}
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -55,14 +68,14 @@ OpenGbg::Service::StyrOchStall - Entry point to the StyrOchStall bike rental ser
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
 
 =head1 SYNOPSIS
 
     my $service = OpenGbg->new->styr_och_stall;
-    my $response = $service->get_bike_stations;
+    my $stations = $service->get_bike_stations;
 
-    print $response->stations->get_by_index(0)->to_text;
+    print $stations->get_by_index(0)->to_text;
 
 =head1 DESCRIPTION
 
@@ -107,7 +120,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
