@@ -1,17 +1,17 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package OpenGbg::Service::StyrOchStall::GetBikeStation;
 
-our $VERSION = '0.1302'; # VERSION
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Get data about a bike station
 
-use OpenGbg::Types -types;
-use Kavorka;
 use XML::Rabbit::Root;
 use DateTime::Format::HTTP;
 use MooseX::AttributeShortcuts;
+use Types::Standard qw/Str/;
+use Types::DateTime qw/DateTime/;
 
 has xml => (
     is => 'ro',
@@ -23,7 +23,8 @@ add_xpath_namespace 'x' => 'TK.DevServer.Services.RentalBikeService';
 
 has_xpath_value _timestamp => '/x:RentalBikes/x:TimeStamp';
 
-has_xpath_object stations => '/x:RentalBikes/x:Stations' => 'OpenGbg::Service::StyrOchStall::Stations';
+has_xpath_object station => '/x:RentalBikes/x:Stations[1]/x:Details' => 'OpenGbg::Service::StyrOchStall::Station',
+    handles => [qw/label capacity free_bikes free_stands full empty to_text/];
 
 has timestamp => (
     is => 'ro',
@@ -32,12 +33,8 @@ has timestamp => (
     builder => 1,
 );
 
-method _build_timestamp {
-    return DateTime::Format::HTTP->parse_datetime($self->_timestamp);
-}
-
-method station {
-    return $self->stations->get_by_index(0);
+sub _build_timestamp {
+    return DateTime::Format::HTTP->parse_datetime(shift->_timestamp);
 }
 
 finalize_class();
@@ -56,26 +53,24 @@ OpenGbg::Service::StyrOchStall::GetBikeStation - Get data about a bike station
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
 
 =head1 SYNOPSIS
 
     my $service = OpenGbg->new->styr_och_stall;
-    my $response = $service->get_bike_station(1);
+    my $station = $service->get_bike_station(1);
 
     printf 'Time: %s', $response->timestamp;
-    print $response->station->to_text;
+    print $station->to_text;
 
 =head1 METHODS
 
+All attributes and methods in L<OpenGbg::Service::StyrOchStall::Station> are available on an instance of this class.
+
 =head2 timestamp
 
 Returns the timestamp given in the response as a L<DateTime> object.
 
-=head2 station
-
-Returns the L<OpenGbg::Service::StyrOchStall::Station> object given in the response.
-
 =head1 SOURCE
 
 L<https://github.com/Csson/p5-OpenGbg>
@@ -90,7 +85,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
