@@ -1,40 +1,52 @@
-use OpenGbg::Standard::Imports;
+use 5.10.1;
+use strict;
+use warnings;
 
-our $VERSION = '0.1302'; # VERSION
-# PODNAME: OpenGbg::Service::TrafficCamera
+package OpenGbg::Service::TrafficCamera;
+
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Entry point to the Traffic Camera service
 
-class OpenGbg::Service::TrafficCamera using Moose {
+use OpenGbg::Elk;
 
-    use OpenGbg::Service::TrafficCamera::GetCameraImage;
-    use OpenGbg::Service::TrafficCamera::GetTrafficCameras;
-    with 'OpenGbg::Service::Getter';
+use namespace::autoclean;
+use Types::Standard qw/Str/;
 
-    has handler => (
-        is => 'ro',
-        required => 1,
-    );
-    has service_base => (
-        is => 'rw',
-        isa => Str,
-        default => 'TrafficCamera/v0.1/',
-    );
+use OpenGbg::Service::TrafficCamera::GetCameraImage;
+use OpenGbg::Service::TrafficCamera::GetTrafficCameras;
+with 'OpenGbg::Service::Getter';
 
-    method get_camera_image($id) {
-        my $url = "CameraImage/%s/$id?";
-        my $response = $self->getter($url, 'get_camera_image');
+has handler => (
+    is => 'ro',
+    required => 1,
+);
+has service_base => (
+    is => 'rw',
+    isa => Str,
+    default => 'TrafficCamera/v0.1/',
+);
 
-        return OpenGbg::Service::TrafficCamera::GetCameraImage->new(image => $response);
-    }
+sub get_camera_image {
+    my $self = shift;
+    my $id = shift;
 
-    method get_traffic_cameras {
-        my $url = 'TrafficCameras/%s?';
-        my $response = $self->getter($url, 'get_traffic_cameras');
+    my $url = "CameraImage/%s/$id?";
+    my $response = $self->getter($url, 'get_camera_image');
 
-        return OpenGbg::Service::TrafficCamera::GetTrafficCameras->new(xml => $response);
-    }
+    return OpenGbg::Service::TrafficCamera::GetCameraImage->new(image => $response);
 }
 
+sub get_traffic_cameras {
+    my $self = shift;
+
+    my $url = 'TrafficCameras/%s?';
+    my $response = $self->getter($url, 'get_traffic_cameras');
+
+    return OpenGbg::Service::TrafficCamera::GetTrafficCameras->new(xml => $response);
+}
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -49,7 +61,7 @@ OpenGbg::Service::TrafficCamera - Entry point to the Traffic Camera service
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
 
 =head1 SYNOPSIS
 
@@ -95,7 +107,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
