@@ -1,16 +1,15 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package OpenGbg::Service::TrafficCamera::GetTrafficCameras;
 
-our $VERSION = '0.1302'; # VERSION
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Get a list of traffic cameras
 
-use OpenGbg::Types -types;
 use XML::Rabbit::Root;
-use MooseX::AttributeShortcuts;
-use Kavorka;
+use Types::Standard qw/Str/;
+
 
 has xml => (
     is => 'ro',
@@ -38,7 +37,7 @@ OpenGbg::Service::TrafficCamera::GetTrafficCameras - Get a list of traffic camer
 
 =head1 VERSION
 
-Version 0.1302, released 2015-01-17.
+Version 0.1400, released 2016-01-28.
 
 =head1 SYNOPSIS
 
@@ -67,7 +66,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
